import Taro, { Component } from '@tarojs/taro'
import echarts from '../ec-canvas/echarts'
import './style.scss'

function initChart(callback, options) {
  return function (canvas, width, height) {
    const chart = echarts.init(canvas, null, {
      width: width,
      height: height
    });
    canvas.setChart(chart);
    chart.setOption(options);
    callback && callback(chart);
    return chart;
  }
}

/**
 * 传入 source 的格式为 [{ name: xxx, value: xxx }, {}]
 */
export default class LineChart extends Component {
  config = {
    usingComponents: {
      "ec-canvas": "../ec-canvas/ec-canvas"
    }
  }

  // this.echart
  echart = null
  ecComponent = null

  state = {
    ec: { lazyLoad: true },
  }

  // 禁止 props 变更时渲染
  shouldComponentUpdate(nextProps) {
    if (nextProps.source && nextProps.source.length) {
      this.refreshChart(this.props.source)
    }

    return false
  }

  handleEcComponent (ref) {
    this.ecComponent = ref
  }

  handleChart(chart) {
    this.echart = chart
  }

  createOptions(source = []) {
    const defaultOpt = {
      color: ['#BB9C79', '#666666'],
      xAxis: { type: 'category' },
      yAxis: { type: 'value' },
      series: [],
    }

    return {
      ...defaultOpt,
      dataset: { source },
      series: [{
        type: 'line',
        areaStyle: {},
        dimensions: ['name', 'value'],
      }],
    }
  }

  refreshChart(source) {    
    const options = this.createOptions(source)

    if (!this.echart) {
      if (this.ecComponent) {
        const initFunc = initChart(this.handleChart.bind(this), options)
        this.ecComponent.init(initFunc)
      } else {
        console.warn('echart componet not ready')
      }
    } else {
      this.echart.setOption(options)
    }
  }

  render() {
    return (
      <View className="map-container">
        <ec-canvas ref={this.handleEcComponent} ec={this.state.ec}></ec-canvas>
      </View>
    )
  }
}
